import React from 'react';
import { Button, Grid, makeStyles } from "@material-ui/core";
import { Alert } from "@material-ui/lab";
import { theme } from '../../style/Theme'; 

const useStyles = makeStyles((theme) => ({
  infoBadge: {
    backgroundColor: theme.infoBadge.bgColor,
  }
}));

export default function AlertMessages({ alerts }) {

  const classes = useStyles(theme);

  function determineSeverity(alarmType) {
    if (alarmType === "ERROR") {
      return "error";
    }

    if(alarmType === "WARNING") {
      return "warning";
    }

    if (alarmType === "SUCCESS") {
      return "success";
    }

    return "info";
  }

  function determineClassName(alarmType) {
    if(alarmType === "INFO") {
      return classes.infoBadge;
    }
  }

  return (
    <Grid id="ioc-alerts" container spacing={1}>
      {(alerts.map((alert) => (
        <Grid item xs={12} key={alert}>
          <Alert className={determineClassName(alert.type)}
            severity={determineSeverity(alert.type)}
            action={ alert.link &&
              <Button target="_blank" href={alert.link} color="inherit" size="small">
                More Info
              </Button>
            }
          >
            {alert.message}
          </Alert>
        </Grid>
      )))}
    </Grid>)
}