import React, { useState, useEffect, useMemo } from "react";
import { ScheduleOutlined, RotateRightOutlined, CheckCircleOutline } from "@material-ui/icons";
import { useCommandJob } from '../../api/SwaggerApi';
import { StepperWithStyle } from "../common/stepper/StepperWithStyle";
import { useSafePolling } from "../../hooks/Polling";
import { AWXCommandDetails } from "../../api/DataTypes";

const POLL_COMMAND_JOB_INTERVAL = 3000;
export function CommandJobStepper({ awxCommandId, actionType }) {
  const [commandJob, getCommandJob, /*reset*/, loading] = useCommandJob(awxCommandId);
  const [activeStep, setActiveStep] = useState(0);
  const [pollJob, setPollJob] = useState(true);
  const commandStatus = useMemo(() => new AWXCommandDetails(commandJob), [commandJob]);

  useEffect(() => {
    if (commandJob) {
      if (commandStatus.notFinished()) {
        if (commandStatus.isRunning()) {
          setActiveStep(1);
        }
      } else {
        if (commandStatus.wasSuccessful()) {
          setActiveStep(3);
        }
        if (commandStatus.wasFailed()) {
          setActiveStep(1);
        }
        setPollJob(false);
      }
    }
  }, [commandJob, commandStatus, getCommandJob]);

  const icons = {
    1: <ScheduleOutlined />,
    2: <RotateRightOutlined />,
    3: <CheckCircleOutline />,
  };

  const steps = ['Queued ', 'Running', (actionType ?? '') + ' Completed'];

  const isStepFailed = (step) => {
    if (commandStatus.wasFailed()) {
      return step === activeStep;
    }
    return false;
  };

  return (
    <>
      <StepperWithStyle steps={steps} activeStep={activeStep} isStepFailed={isStepFailed} icons={icons} />
      {pollJob && <CommandJobWatcher {...{ getCommandJob, loading }} />}
    </>
  )
}

function CommandJobWatcher({getCommandJob, loading}) {
  useSafePolling(getCommandJob, loading, POLL_COMMAND_JOB_INTERVAL);
  return null;
}