import { mount } from "@cypress/react";
import { SnackbarProvider } from "notistack";
import React, { useContext } from "react";
import { APIProvider, userContext, UserProvider } from "../../../api/SwaggerApi";
import { useEffectOnMount } from "../../../hooks/MountEffects";
import { notificationContext, NotificationProvider } from "./Notifications";

function AppHarness({ children }) {
  return (
    <SnackbarProvider preventDuplicate maxSnack="5">
      <APIProvider>
        <UserProvider>
          {children}
        </UserProvider>
      </APIProvider>
    </SnackbarProvider>
  )
}

function mountIntoHarness(children) {
  mount(<AppHarness>{children}</AppHarness>)
}

function DisplayContextValue({context}) {
  const {login} = useContext(userContext);
  const contextValue = useContext(context);
  console.log(contextValue);
  useEffectOnMount(() => login());

  return (
    <pre id="display">
      {JSON.stringify(contextValue, (key, val) => (typeof(val) === "function") ? val.toString() : val, 2)}
    </pre>
  )
}

describe("Notifications", () => {
  context("when logged in", () => {
    beforeEach(() => {
      cy.login();
    })

    it("Provides the notification context", () => {      
      mountIntoHarness(
        <NotificationProvider>
          <DisplayContextValue context={notificationContext} />
        </NotificationProvider>
      )
      
      cy.wait("@infoFromUserName");
      cy.wait("@getUserRoles")

      cy.get("#display")
        .contains("notifications")
        .contains("watchDeployment")
        .contains("watchCommand")
        .contains("clearNotifications")
    })
  })
})