import React from 'react';
import { CustomTable } from "../common/table/CustomTable";
import { Grid, Tooltip } from "@material-ui/core";
import { DeploymentStatusIcon, DeploymentTypeIcon } from './DeploymentIcons';
import { formatDate, noWrapText } from '../common/Helper';
import { useRedirect } from '../../hooks/Redirect';

const formatDeploymentDate = (value) => {
  if (value) {
    return formatDate(value);
  }
  return "Not started yet";
}

const columns = [
  { id: 'type', label: 'Type', width: '8ch', textAlign: "center"},
  { id: 'ioc', label: 'IOC Name', width: '15ch', sortable: true },
  { id: 'host', label: 'Host', width: '15ch', sortable: false },
  { id: 'network', label: 'Network', width: '10ch', sortable: false },
  { id: 'user', label: 'User', width: '10ch', sortable: true },
  { id: 'version', label: 'Reference', width: '15ch', sortable: true },
  { id: 'start', label: 'Time', width: '10ch', sortable: true }
];

function createGitVersionField(version, shortVersion) {
  return (
    <Tooltip title={version} arrow enterDelay={400}>
      <label>{noWrapText(shortVersion ?? version)}</label>
    </Tooltip>
  )
}

function createTableRow(deployment) {
  return {
    id: deployment.id,
    type:
      <Grid container direction="column" justifyContent="center" alignItems="center">
        <DeploymentTypeIcon type={deployment.undeployment ? "undeploy" : "deploy"} />
      </Grid>,
    status:
      <Grid container direction="column" justifyContent="center" alignItems="center">
        <DeploymentStatusIcon status={deployment.status} />
      </Grid>,
    ioc: noWrapText(deployment.namingName),
    version: createGitVersionField(deployment.sourceVersion, deployment.sourceVersionShort),
    host: noWrapText(deployment.host?.hostName ?? null),
    network: noWrapText(deployment.host?.network ?? null),
    user: noWrapText(deployment.createdBy),
    start: noWrapText(formatDeploymentDate(deployment.startDate)),
    deploymentFailed: deployment.status === 'FAILED'
  };
}

export function DeploymentsTable({ deployments, totalCount, lazyParams, setLazyParams, columnSort, setColumnSort, rowsPerPage, loading }) {
  const redirect = useRedirect();

  const itemLink = id => `/deployments/${id}`;

  const onRowClicked = (id) => {
    redirect(itemLink(id));
  };

  return (
    <CustomTable columns={columns} rows={deployments.map(deployment => createTableRow(deployment))} handleRowClick={onRowClicked} itemLink={itemLink}
      totalCount={totalCount} lazyParams={lazyParams} setLazyParams={setLazyParams} columnSort={columnSort} setColumnSort={setColumnSort}
      rowsPerPage={rowsPerPage} loading={loading} />
  );
}