import React from "react";
import { mount } from "@cypress/react";
import { composeStories } from "@storybook/testing-react";
import * as stories from "./DeploymentsTable.stories";

const {AfterAsync} = composeStories(stories)
const textColumns = ["IOC Name", "Host", "Network", "User", "Reference", "Time"];
const columns = ["Type"].concat(textColumns);
const firstRowData = ["Deployment", "YMIR-TS:SC-IOC-002", "ymir-ts-ipc-02", "NIN-Inst-Ymir", "nicklasholmberg2", "96af1a85", "Not started yet"]


describe("HostTable", () => {
  context("Populated Table", () => {
    beforeEach(() => {
      mount(<AfterAsync />)
    })

    it("Has the correct columns", () => {
      cy.get(".p-column-title").each(($el, index) => {
        console.log(index, columns[index]);
        cy.wrap($el).contains(columns[index], { matchCase: false });
      })
    })

    it("Truncates all text content", () => {
      cy.get("tbody > tr").first()
        .find(".MuiTypography-noWrap")
        .should("have.length", textColumns.length)
    })

    it("Displays correct content in first row", () => {
      cy.get("tbody > tr").first()
        .find("td")
        .each(($el, index) => {
          if (index === 0) {
            cy.wrap($el).find("svg")
          }
          else {
            cy.wrap($el).find("p").should($el => {
              const text = $el.text().trim().toLowerCase()
              const expected = firstRowData[index].trim().toLowerCase()
              cy.expect(text).to.equal(expected);
            })
          }
        })
    })
  })
})
