import React, { useContext, useEffect } from "react";
import { CookiesProvider } from "react-cookie";
import { useCookies } from "react-cookie";
import { userContext } from "../../../api/SwaggerApi";
import { useEffectOnMount } from "../../../hooks/MountEffects";
import { useRedirect } from "../../../hooks/Redirect";

export function LoginSuggester({ children }) {
  return (
    <CookiesProvider>
      <LoginSuggesterMechanics />
      {children}
    </CookiesProvider>
  )
}

export function LoginSuggesterMechanics() {
  const redirect = useRedirect();
  const { user } = useContext(userContext);
  const [cookies, setCookie] = useCookies(['ce-return-customer', 'ce-has-logged-in']);

  useEffectOnMount(() => {
    let suggestLogin = false;

    // check if it's the first time a user has visited
    // the app or they have logged in in the past. 
    // If so, redirect them to the login page.
    if (!("ce-has-visited" in cookies)) {
      setCookie("ce-has-visited", true);
      suggestLogin = true;
    }
    else if ("ce-has-logged-in" in cookies) {
      if (!user) {
        suggestLogin = true;
      }
    }

    // Don't suggest login if the user has refreshed the page
    const navigationType = window.performance.getEntriesByType("navigation")[0].type
    suggestLogin &= (navigationType !== "reload")

    if (suggestLogin) {
      redirect("/login");
    }
  })

  // When people log in, set a cookie
  // we can use to suggest login the next time.
  useEffect(() => {
    if (user) {
      setCookie("ce-has-logged-in", true);
    }
  }, [setCookie, user])

  return null;
}