import React from "react";
import clsx from 'clsx';
import { Container, Drawer, IconButton, Box, Tooltip, makeStyles, useTheme } from "@material-ui/core";
import ChevronLeftIcon from '@material-ui/icons/ChevronLeft';
import ChevronRightIcon from '@material-ui/icons/ChevronRight';

const useStyles = makeStyles((theme) => ({
  footer: {
    position: "fixed",
    bottom: 0,
    paddingBottom: theme.spacing(2),
  },
  drawer: {
    width: theme.drawer.widthOpen,
    flexShrink: 0,
    whiteSpace: 'nowrap',
  },
  drawerOpen: {
    width: theme.drawer.widthOpen,
    transition: theme.transitions.create('width', {
      easing: theme.transitions.easing.sharp,
      duration: theme.transitions.duration.enteringScreen,
    }),
  },
  drawerClose: {
    transition: theme.transitions.create('width', {
      easing: theme.transitions.easing.sharp,
      duration: theme.transitions.duration.leavingScreen,
    }),
    overflowX: 'hidden',
    width: theme.drawer.widthClose,
    [theme.breakpoints.up('sm')]: {
      width: theme.spacing(9) + 1,
    },
  },
  toggleButton: {
    marginRight: theme.spacing(1),
  },
}));

export function MenuDrawer({ open, toggleDrawer, children }) {
  const theme = useTheme();
  const classes = useStyles();

  const handleDrawerClose = () => {
    toggleDrawer();
  };

  return (
    <>
      <Drawer
        variant="permanent"
        className={clsx(classes.drawer, {
          [classes.drawerOpen]: open,
          [classes.drawerClose]: !open,
        })}
        classes={{
          paper: clsx({
            [classes.drawerOpen]: open,
            [classes.drawerClose]: !open,
          }),
        }}
        open={open}
        onClose={toggleDrawer}
        ModalProps={{
          keepMounted: true, // Better open performance on mobile.
        }}
      >
        <Container disableGutters="true">
          <div style={{ ...theme.mixins.toolbar }} />
          <div style={{ paddingTop: theme.spacing(2), paddingBottom: theme.spacing(2) }} >
          {children}
          </div>
          <div className={classes.footer}>
            <Box display="flex" 
              className={clsx(classes.drawer, {
                  [classes.drawerOpen]: open,
                  [classes.drawerClose]: !open,
                })} 
              flexDirection="row-reverse" p={1} m={1}>
              <Tooltip title={open ? "Collapse sidebar" : "Expand sidebar"} placement="right" arrow>
                <IconButton onClick={handleDrawerClose} className={classes.toggleButton}>
                  {open ? <ChevronLeftIcon /> : <ChevronRightIcon />}
                </IconButton>
              </Tooltip>
            </Box>
          </div>
        </Container>
      </Drawer>
    </>
  );
}