import { createMuiTheme } from "@material-ui/core/styles";
import { chartColors } from "./Palette";
import createBreakpoints from "@material-ui/core/styles/createBreakpoints";

const breakpoints = createBreakpoints({});

export const theme = createMuiTheme({
  breakpoints,
  overrides: {
      MuiTooltip: {
          tooltip: {
            fontSize: 15,
            backgroundColor: "#707070ff",
          },
      },
      MuiListItem: {
        root: {
          '&$selected, &$selected:hover': {
            backgroundColor: "#ccccccff",
          },
        },
        button: {
          "&:hover": {
            backgroundColor: "#ddddddff",
          }
        },
    },
  },
  props: { MuiWithWidth: { initialWidth: 'lg' } },
  drawer: {
    widthOpen: 240,
    widthClose: 57,
  },
  palette: {
    primary: {
      main: "#0099dc"
    },
    secondary: {
      main: "#0d598e"
    },
    status: {
      ok: '#4caf50',
      fail: '#aa2e25',
      neutral: '#000',
      progress: '#ffc107',
    },
    graph: chartColors,
  },
  typography: {
    fontFamily:[
      '-apple-system',
      'BlinkMacSystemFont',
      '"Segoe UI"',
      'Roboto',
      '"Helvetica Neue"',
      'Arial',
      'Noto Sans',
      'sans-serif',
      '"Apple Color Emoji"',
      '"Segoe UI Emoji"',
      '"Segoe UI Symbol"',
      '"Noto Color Emoji"',
    ].join(','),
    h1: {
      fontFamily: 'Titillium Web, sans-serif',
      [breakpoints.down('md')]: {
        fontSize: 18,
      },
      [breakpoints.up('md')]: {
        fontSize: 24,
      },
    },
    h2: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 25,
      },
      [breakpoints.up('md')]: {
        fontSize: 34,
      },
      fontWeight: 600,
    },
    h3: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 23,
      },
      [breakpoints.up('md')]: {
        fontSize: 32,
      },
      fontWeight: 600,
    },
    h4: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 18,
      },
      [breakpoints.up('md')]: {
        fontSize: 20,
      },
      fontWeight: 600,
    },
    h5: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 15,
      },
      [breakpoints.up('md')]: {
        fontSize: 16,
      },
      fontWeight: 600,
    },
    h6: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 14,
      },
      [breakpoints.up('md')]: {
        fontSize: 16,
      },
      fontWeight: 600,
    },
    overline: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 12,
      },
      [breakpoints.up('md')]: {
        fontSize: 16,
      },
      fontWeight: 600,
    },
    body1: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 14,
        fontWeight: 600,
      },
      [breakpoints.down('md')]: {
        fontSize: 16,
      },
    },
    button: {
      fontFamily: [
        "Segoe UI",
        'Roboto',
        'Noto Sans',
      ].join(','),
      [breakpoints.down('md')]: {
        fontSize: 12,
      },
      [breakpoints.up('md')]: {
        fontSize: 14,
      },
      fontWeight: 500,
    }
  },
  'cccecustomtable': {
    fontSize: 14,
  },
  infoBadge: {
    bgColor: '#ececec'
  },
  iocNotDeployed: {
    color: '#b2b2b2'
  },
  csentryIdInvalid: {
    color: '#b2b2b2'
  }
});

