import { Container, Grid, Paper, FormControlLabel, Switch, Typography, Tabs, Tab } from "@material-ui/core";
import { RootContainer } from "../../components/common/Container/RootContainer";
import React, { useState, useEffect, useContext } from "react"
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { IOCAsyncList } from "../../components/IOC/IOCAsyncList";
import { useIOCSearch, userContext } from "../../api/SwaggerApi";
import { makeStyles } from '@material-ui/core/styles';
import { initRequestParams } from "../../components/common/Helper";
import { SearchBar } from "../../components/common/SearchBar/SearchBar";
import AccessControl from '../../components/auth/AccessControl';

const useStyles = makeStyles((theme) => ({
    root: {
        marginBottom: theme.spacing(2),
    },
}));

export function IOCListView() {
    const [iocs, getIocs, /*reset*/, loading] = useIOCSearch();
    const [iocList, setIocList] = useState([]);
    const [query, setQuery] = useState("");
    const [ownOnly, setOwnOnly] = useState(false);
    const [selectedTab, setSelectedTab] = useState(0);
    const [deploymentStatus, setDeploymentStatus] = useState("ALL");
    const { user } = useContext(userContext);
    const classes = useStyles();

    const handleTabChange = (event, tab) => {
        setSelectedTab(tab);

        if (tab === 0) {
            setDeploymentStatus("ALL");
        }
        else if (tab === 1) {
            setDeploymentStatus("DEPLOYED");
        }
        else if (tab === 2) {
            setDeploymentStatus("NOT_DEPLOYED");
        }
    };

    const [lazyParams, setLazyParams] = useState({
        first: 0,
        rows: 20,
        page: 0
    });

    const handleChangeOwn = (event) => {
        const own = event.target.checked;
        setOwnOnly(own);
    };

    const rowsPerPage = [20, 50];

    useEffect(() => {
        setIocList(iocs.iocList);
    }, [iocs, setIocList])

    useEffect(() => {
        let requestParams = initRequestParams(lazyParams, query);

        if (ownOnly) {
            requestParams.owner = user?.loginName;
        }

        requestParams.deployment_status = deploymentStatus;

        getIocs(requestParams);
    }, [getIocs, lazyParams, query, user, ownOnly, deploymentStatus])

    const title = "IOCs";
    useGlobalAppBar(title);

    let content = (
        <SearchBar search={setQuery} loading={loading} placeholder="search in IOC name or user">
            <IOCAsyncList iocs={iocList} setIocs={setIocList} loading={loading} rowType="explore"
                lazyParams={lazyParams} setLazyParams={setLazyParams} totalCount={iocs.totalCount}
                rowsPerPage={rowsPerPage} />
        </SearchBar>
    );

    return (
        <RootContainer>
            <Paper className={classes.root}>
                <Grid container spacing={1}>
                    <Grid container spacing={1} component={Container} justify="space-between" alignItems="center" style={{ display: "flex" }} >
                        <Grid item>
                            <Tabs
                                value={selectedTab}
                                onChange={handleTabChange}
                                indicatorColor="primary"
                                textColor="primary">
                                <Tab label={<Typography variant="h5">All</Typography>} />
                                <Tab label={<Typography variant="h5">Only Deployed</Typography>} />
                                <Tab label={<Typography variant="h5">Only Not Deployed</Typography>} />
                            </Tabs>
                        </Grid>
                        <Grid item>
                            <AccessControl allowedRoles={["DeploymentToolAdmin", "DeploymentToolIntegrator"]}
                                renderNoAccess={() => <></>} >
                                <FormControlLabel className={classes.formControl}
                                    control={<Switch checked={ownOnly} onChange={handleChangeOwn} />}
                                    label={<Typography variant="h5">Only my IOCs</Typography>}
                                />
                            </AccessControl>
                        </Grid>
                    </Grid>
                    <Grid item xs={12} md={12}>
                        {content}
                    </Grid>
                </Grid>
            </Paper>
        </RootContainer>
    );
}

