import React from "react";
import {
  Paper,
  Link,
  Typography,
  makeStyles,
} from "@material-ui/core";
import { useGlobalAppBar } from "../../components/navigation/GlobalAppBar/GlobalAppBar";
import { RootContainer } from "../../components/common/Container/RootContainer";

const useStyles = makeStyles((theme) => ({
  paper: {
    padding: theme.spacing(4),
  },
}));

export function AboutView() {
  const classes = useStyles();
  const title = "About";
  useGlobalAppBar(title);

  return (
    <RootContainer>
      <h2>About</h2>
      <Paper className={classes.paper}>

        <Typography variant="body1">
          This is the <Link href="https://confluence.esss.lu.se/x/CVGQFg" target="_blank" rel="noreferrer">deployment and monitoring</Link> parts of the IOC toolchain in the controls ecosystem (CE); working name &quot;CE deploy & monitor&quot;. It is a tool that manages IOCs on host machines, using Ansible to perform the necessary configuration management. This tool will set up IOC-hosts and deploy IOC(s) in a consistent manner, and will configure all necessary services towards this purpose. The tool also integrates with various other systems to enable monitoring of IOCs and hosts, and enables some limited remote execution features.

          <p>Be aware that the tool does <b>not</b> set up your host (and OS) - this needs to be done in CSEntry.</p>

          <p>IOCs with divergences or issues will raise various warnings - there will be yellow or red backgrounds and annotations if issues are detected.</p>

          <p>Users without access can only access a subset of the features of the application.</p>

          <p>If you wish to visualise or interact directly with the REST API, you can use the <Link
            href={`${window.SERVER_ADDRESS}${window.SWAGGER_UI_URL}`} target="_blank" rel="noreferrer">Swagger UI</Link>.</p>

          <hr />

          <h3>Application info</h3>
          <table>
            <tr>
              <td>Front-end:</td>
              <td><Link href={`${window.FRONTEND_REPOSITORY_TAGS}${window.FRONTEND_VERSION}`} target="_blank" rel="noreferrer">{`${window.FRONTEND_VERSION}`}</Link></td>
            </tr>
            <tr>
              <td>Back-end:</td>
              <td><Link href={`${window.BACKEND_REPOSITORY_TAGS}${window.BACKEND_VERSION}`} target="_blank" rel="noreferrer">{`${window.BACKEND_VERSION}`}</Link></td>
            </tr>
          </table>
        </Typography>
      </Paper>
    </RootContainer>
  )
}